@@ -1,5 +1,8 @@
 use crate::markdown::line::{Line, LineType};
-use self::decoration::render_code_spans;
+use crate::markdown::math::render_math;
+use self::decoration::*;
+use self::tag::render_tag;
+use self::link::render_link;
 
 mod decoration;
 pub mod link;
@@ -14,21 +17,18 @@ I can't figure out nice way to deal with multiple nested inline elements. I can'
 *inlines are rendered sequentially, in this order*
 
 code span
-link
-image
+math
+link & image
 italic
 bold
+underline   // it has to be rendered before subscript
 del
-underline
 subscript
 superscript
-alignment
-color
-size
-box
+alignment & color & size & box & special chars & svg
 --- implemented so far
-svg
 footnote
+collapsible
 */
 
 
@@ -57,5 +57,18 @@ pub fn render_inline(mut line: Line) -> Line {
 
 
 pub fn render_inline_raw(content: &Vec<u16>) -> Vec<u16> {
-    render_code_spans(content)
+    let mut content = render_code_spans(content);
+    content = render_math(&content);
+    content = render_link(&content);
+    content = render_bold_and_italic(&content);
+    content = render_italic(&content);
+    content = render_bold(&content);
+    content = render_underline(&content);
+    content = render_subscript_and_del(&content);
+    content = render_del(&content);
+    content = render_subscript(&content);
+    content = render_superscript(&content);
+    content = render_tag(&content);
+
+    content
 }
\ No newline at end of file
