@@ -232,7 +232,7 @@ fn parse_icon(content: &[u16]) -> Option<Vec<u16>> {
         }
     };
 
-    get_icon(&curr_icon, curr_size, None)
+    get_icon(&curr_icon, curr_size, None, false)
 }
 
 // if true, it's possibly a valid char
